Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(737)

Unified Diff: pkg/docgen/test/multi_library_code/lib/temp3.dart

Issue 183333003: Adding 'preview' to typedef (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: added back _moveDirectoryAndServe Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« pkg/docgen/lib/docgen.dart ('K') | « pkg/docgen/test/generate_json_test.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/docgen/test/multi_library_code/lib/temp3.dart
diff --git a/pkg/docgen/test/multi_library_code/lib/temp3.dart b/pkg/docgen/test/multi_library_code/lib/temp3.dart
index 01137e718d4f0887e38d16afed4306046398f172..fa1d74a967f64f84847e434c05a74148181eebda 100644
--- a/pkg/docgen/test/multi_library_code/lib/temp3.dart
+++ b/pkg/docgen/test/multi_library_code/lib/temp3.dart
@@ -7,7 +7,7 @@ import 'temp.dart';
class C {
}
-// A trivial use of `A` to eliminate import warnings
-A usingImport() {
- throw new UnimplementedError();
-}
+/// A trivial use of `A` to eliminate import warnings.
+///
+/// And to test typedef preview.
+typedef A AnATransformer(A input);
« pkg/docgen/lib/docgen.dart ('K') | « pkg/docgen/test/generate_json_test.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698